@@ -16,7 +16,7 @@ import warnings
 
 from packaging import version
 
-__version__ = "2.0.4"
+__version__ = "2.0.6"
 
 # This is mostly here so automodule docs are ordered more ideally.
 __all__ = ["deprecated", "message_location", "fail_if_not_removed",
@@ -56,7 +56,8 @@ class DeprecatedWarning(DeprecationWarning):
         self.deprecated_in = deprecated_in
         self.removed_in = removed_in
         self.details = details
-        super(DeprecatedWarning, self).__init__()
+        super(DeprecatedWarning, self).__init__(function, deprecated_in,
+                                                removed_in, details)
 
     def __str__(self):
         # Use a defaultdict to give us the empty string
@@ -259,7 +260,9 @@ def fail_if_not_removed(method):
              :class:`~deprecation.UnsupportedWarning`
              is raised while running the test method.
     """
-    def _inner(*args, **kwargs):
+    # NOTE(briancurtin): Unless this is named test_inner, nose won't work
+    # properly. See Issue #32.
+    def test_inner(*args, **kwargs):
         with warnings.catch_warnings(record=True) as caught_warnings:
             warnings.simplefilter("always")
             rv = method(*args, **kwargs)
@@ -270,4 +273,4 @@ def fail_if_not_removed(method):
                     ("%s uses a function that should be removed: %s" %
                      (method, str(warning.message))))
         return rv
-    return _inner
+    return test_inner
